plot.pehaz: Plot a pehaz object.

View source: R/all.R

plot.pehazR Documentation

Plot a pehaz object.

Description

A plot of the pehaz object is produced on the current device. If lines.pehaz was called then the estimated curve is added to the current plot.

Usage

## S3 method for class 'pehaz'
plot(x, xlab="Time", ylab="Hazard Rate", ...)
## S3 method for class 'pehaz'
lines(x, lty=2, ...)

Arguments

x

A pehaz object.

xlab

The x-axis label.

ylab

The y-axis label.

lty

The line type to use when plotting.

...

Other graphical parameters, passed to plot

Value

No value is returned, the object is plotted on the active device.

See Also

pehaz.object

Examples

  data(cancer, package="survival")
  attach(ovarian)
  fit <- pehaz(futime, fustat)
  plot(fit)

muhaz documentation built on July 29, 2026, 9:07 a.m.