Learn R Programming

muhaz (version 1.2.6.5)

plot.pehaz: Plot a pehaz object.

Description

A plot of the pehaz object is produced on the current device. If lines.pehaz was called then the estimated curve is added to the current plot.

Usage

# S3 method for pehaz
plot(x, xlab="Time", ylab="Hazard Rate", ...)
# S3 method for pehaz
lines(x, lty=2, ...)

Value

No value is returned, the object is plotted on the active device.

Arguments

x

A pehaz object.

xlab

The x-axis label.

ylab

The y-axis label.

lty

The line type to use when plotting.

...

Other graphical parameters, passed to plot

See Also

pehaz.object

Examples

Run this code
  data(cancer, package="survival")
  attach(ovarian)
  fit <- pehaz(futime, fustat)
  plot(fit)

Run the code above in your browser using DataLab